<?php

namespace Drupal\image_transformation_api\Form;

use Drupal\Core\Entity\ContentEntityTypeInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\gatsby\PathMapping;

/**
 * Defines a config form to store Gatsby configuration.
 */
class ImageTransformationAPIAdminForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'image_transformation_api.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'image_transformation_api_admin_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('image_transformation_api.settings');
    $form['enable_signing'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable signing'),
      '#description' => $this->t('If enabled, transformation URLs must include a ?s=[signature] query paramater which has been generated by hashing the requested transformations.'),
      '#default_value' => $config->get('enable_signing'),
    ];
    $form['private_key'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Private Signing Key'),
      '#description' => $this->t('Private key used to sign transformations.'),
      '#default_value' => $config->get('private_key'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('image_transformation_api.settings')
      ->set('enable_signing', $form_state->getValue('enable_signing'))
      ->set('private_key', $form_state->getValue('private_key'))
      ->save();
  }

}
